@@ -3,7 +3,6 @@ arc2_cache <- NULL
 lcd_cache <- NULL
 bsw_cache <- NULL
 isd_cache <- NULL
-storms_cache <- NULL
 stormevents_cache <- NULL
 ersst_cache <- NULL
 torn_cache <- NULL
@@ -30,10 +29,6 @@ ghcnd_cache <- NULL
   g$cache_path_set("noaa_isd")
   isd_cache <<- g
 
-  s <- hoardr::hoard()
-  s$cache_path_set("noaa_storms")
-  storms_cache <<- s
-
   ss <- hoardr::hoard()
   ss$cache_path_set("noaa_stormevents")
   stormevents_cache <<- ss
