@@ -11,7 +11,7 @@
 #' @return data.frame if `format="shp"` (a fortified sp object);
 #' `raster::raster()` if not
 #' @seealso [sea_ice_tabular()]
-#' @references See the "User Guide" pdf at https://nsidc.org/data/g02135
+#' @references See the "User Guide" pdf at 
 #' @examples \dontrun{
 #' if (requireNamespace("raster")) {
 #'
@@ -29,11 +29,6 @@
 #' ## many years, one month, one pole
 #' sea_ice(year = 1990:1992, month = "Sep", pole = "N")
 #'
-#' # Map a single year/month/pole combo
-#' out <- sea_ice(year = 1990, month = 'Apr', pole = 'N')
-#' library('sf')
-#' plot(out[[1]])
-#' 
 #' # get geotiff instead of shp data. 
 #' x <- sea_ice(year = 1990, month = "Apr", format = "geotiff-extent")
 #' y <- sea_ice(year = 1990, month = "Apr", format = "geotiff-conc")
@@ -55,7 +50,7 @@ sea_ice <- function(year = NULL, month = NULL, pole = NULL, format = "shp",
     lapply(urls, readshpfile, ...)
   } else {
     check4pkg("raster")
-    lapply(urls, raster::raster, ...)
+    lapply(urls, function(w) suppressWarnings(raster::raster(w, ...)))
   }
 }
 
@@ -214,8 +209,9 @@ readshpfile <- function(x, storepath = NULL) {
   dir.create(path_write, showWarnings = FALSE)
   unzip(path, exdir = path_write)
   my_layer <- rgdal::ogrListLayers(path.expand(path_write))
-  ggplot2::fortify(rgdal::readOGR(path.expand(path_write), layer = my_layer,
-    verbose = FALSE, stringsAsFactors = FALSE))
+  ggplot2::fortify(
+    suppressWarnings(rgdal::readOGR(path.expand(path_write), layer = my_layer,
+      verbose = FALSE, stringsAsFactors = FALSE)))
 }
 
 #' ggplot2 map theme
